==> qmmp-plugin-pack_2.2.2.orig.tar.bz2: qmmp-plugin-pack-2.2.2/src/Input/modplug/translations/modplug_plugin_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="45"/>
        <source>ModPlug Plugin</source>
        <translation>ModPlug 플러그인</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="51"/>
        <source>ModPlug Files</source>
        <translation>ModPlug 파일</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>ModPlug 오디오 플러그인 정보</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Qmmp ModPlug 오디오 플러그인</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>작성자: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Xmms용 Modplug 플러그인에 기반함</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Modplug Plugin developers:</source>
        <translation>Modplug 플러그인 개발자:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="141"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="142"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="70"/>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>Tempo</source>
        <translation>박자</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="72"/>
        <location filename="../modplugmetadatamodel.cpp" line="93"/>
        <source>Samples</source>
        <translation>샘플</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="73"/>
        <location filename="../modplugmetadatamodel.cpp" line="102"/>
        <source>Instruments</source>
        <translation>악기</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="74"/>
        <source>Patterns</source>
        <translation>패턴</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="75"/>
        <source>Channels</source>
        <translation>채널</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="107"/>
        <source>Comment</source>
        <translation>해설</translation>
    </message>
</context>
<context>
    <name>ModPlugSettingsDialog</name>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>ModPlug 플러그인 설정</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>해상도</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16비트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8비트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>채널</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>스테레오</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>모노 (다운믹스)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>리샘플링</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>가장 가까움 (가장 빠름)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>선형 (빠름)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Spline (좋은 품질)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (매우 높은 품질)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>샘플링 레이트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>효과</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation>에코</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="202"/>
        <location filename="../modplugsettingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>깊이 (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="234"/>
        <location filename="../modplugsettingsdialog.ui" line="368"/>
        <location filename="../modplugsettingsdialog.ui" line="499"/>
        <location filename="../modplugsettingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="260"/>
        <location filename="../modplugsettingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>지연시간 (ms)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation>베이스 부스트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>양 (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>범위 (Hz)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation>서라운드</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation>프리앰프</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>볼륨</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>참고: 프리앰프를 너무 높게 설정하면
클리핑이 발생할 수 있습니다!</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>기타</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>곡 제목으로 파일이름 사용</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>소음 감소</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation>빠른 재생목록 정보</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Amiga MOD 재생</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>루핑</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>루프하지 않음</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>루프</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>시간</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>끊임없이 루프</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-2.3.0.tar.bz2: qmmp-plugin-pack-2.3.0/src/Input/modplug/translations/modplug_plugin_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="45"/>
        <source>ModPlug Plugin</source>
        <translation>ModPlug 플러그인</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="51"/>
        <source>ModPlug Files</source>
        <translation>ModPlug 파일</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>ModPlug 오디오 플러그인 정보</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Qmmp ModPlug 오디오 플러그인</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>작성자: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Xmms용 Modplug 플러그인에 기반함</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Modplug Plugin developers:</source>
        <translation>Modplug 플러그인 개발자:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="141"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="142"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="70"/>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>Tempo</source>
        <translation>박자</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="72"/>
        <location filename="../modplugmetadatamodel.cpp" line="93"/>
        <source>Samples</source>
        <translation>샘플</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="73"/>
        <location filename="../modplugmetadatamodel.cpp" line="102"/>
        <source>Instruments</source>
        <translation>악기</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="74"/>
        <source>Patterns</source>
        <translation>패턴</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="75"/>
        <source>Channels</source>
        <translation>채널</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="107"/>
        <source>Comment</source>
        <translation>해설</translation>
    </message>
</context>
<context>
    <name>ModPlugSettingsDialog</name>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>ModPlug 플러그인 설정</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>해상도</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16비트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8비트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>채널</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>스테레오</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>모노 (다운믹스)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>리샘플링</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>가장 가까움 (가장 빠름)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>선형 (빠름)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Spline (좋은 품질)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (매우 높은 품질)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>샘플링 레이트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>효과</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation>에코</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="202"/>
        <location filename="../modplugsettingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>깊이 (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="234"/>
        <location filename="../modplugsettingsdialog.ui" line="368"/>
        <location filename="../modplugsettingsdialog.ui" line="499"/>
        <location filename="../modplugsettingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="260"/>
        <location filename="../modplugsettingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>지연시간 (ms)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation>베이스 부스트</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>양 (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>범위 (Hz)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation>서라운드</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation>프리앰프</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>볼륨</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>참고: 프리앰프를 너무 높게 설정하면
클리핑이 발생할 수 있습니다!</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>기타</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>곡 제목으로 파일이름 사용</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>소음 감소</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation>빠른 재생목록 정보</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Amiga MOD 재생</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>반복 재생</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>반복 안함</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>반복</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>시간</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>무한 반복</translation>
    </message>
</context>
</TS>
